from seven_jd.jd.api.base import RestApi

class ProductConfigSdkServiceSetProductConfigRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.productConfigReq = None

		def getapiname(self):
			return 'jingdong.productConfigSdkService.setProductConfig'

			
	

class Attribute1(object):
		def __init__(self):
			"""
			"""
			self.skuStockNum = None
			self.promiseDays = None
			self.czFlag = None
			self.skuId = None


class ProductConfigReq(object):
		def __init__(self):
			"""
			"""
			self.productConfigInfoDtoList = None








from seven_jd.jd.api.base import RestApi

class JmOrderGetPayUrlRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.serviceCode = None
			self.accessCode = None
			self.orderNum = None
			self.skuId = None
			self.clientIp = None

		def getapiname(self):
			return 'jingdong.jm.order.getPayUrl'

			








# -*- coding:utf-8 -*-
class SecurityException(Exception):
    def __init__(self, value):
        self.value = value

    def __str__(self):
        return repr(self.value)


class MalformedException(SecurityException):
    pass


class CorruptKeyException(SecurityException):
    pass


class NoValidKeyException(SecurityException):
    pass


class ServiceErrorException(SecurityException):
    pass


class InvalidTokenException(SecurityException):
    pass


class InvalidKeyException(SecurityException):
    pass


class InvalidKeyPermission(SecurityException):
    pass


class RequestVoucherException(SecurityException):
    pass


from seven_jd.jd.api.base import RestApi

class SellerPromotionCreateRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.ip = None
			self.port = None
			self.request_id = None
			self.name = None
			self.beginTime = None
			self.endTime = None
			self.bound = None
			self.member = None
			self.slogan = None
			self.comment = None
			self.platform = None
			self.favorMode = None
			self.shopMember = None
			self.qqMember = None
			self.plusMember = None
			self.samMember = None
			self.tokenId = None
			self.promoChannel = None
			self.memberLevelOnly = None
			self.tokenUseNum = None
			self.allowOthersOperate = None
			self.allowOthersCheck = None
			self.allowOtherUserOperate = None
			self.allowOtherUserCheck = None
			self.needManualCheck = None
			self.previewsId = None
			self.previewsContent = None
			self.previewsTime = None
			self.skuIconId = None
			self.skuIconShowTime = None
			self.promoAreaType = None
			self.promoArea = None
			self.showTokenPrice = None
			self.skuId = None
			self.bindType = None
			self.promoPrice = None
			self.num = None
			self.wareId = None
			self.skuName = None
			self.jdPrice = None
			self.itemNum = None
			self.type = None
			self.propsNum = None
			self.usedWay = None
			self.couponValidDays = None
			self.freqBound = None
			self.perMaxNum = None
			self.perMinNum = None
			self.pin = None
			self.useBeginTime = None
			self.useEndTime = None
			self.open_id_buyer = None
			self.xid_buyer = None

		def getapiname(self):
			return 'jingdong.seller.promotion.create'

			








from seven_jd.jd.api.base import RestApi

class EdiInventorySendRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.vendorCode = None
			self.vendorName = None
			self.vendorProductId = None
			self.inventoryDate = None
			self.totalQuantity = None
			self.estimateDate = None
			self.totalEstimateQuantity = None
			self.costPrice = None
			self.storeId = None
			self.storeName = None
			self.quantity = None
			self.estimateQuantity = None

		def getapiname(self):
			return 'jingdong.edi.inventory.send'

			








from seven_jd.jd.api.base import RestApi

class SellerCouponWriteCreateRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.ip = None
			self.port = None
			self.name = None
			self.type = None
			self.bindType = None
			self.grantType = None
			self.num = None
			self.discount = None
			self.quota = None
			self.validityType = None
			self.days = None
			self.beginTime = None
			self.endTime = None
			self.password = None
			self.batchKey = None
			self.member = None
			self.takeBeginTime = None
			self.takeEndTime = None
			self.takeRule = None
			self.takeNum = None
			self.display = None
			self.platformType = None
			self.platform = None
			self.shareType = None
			self.activityLink = None
			self.userClass = None
			self.paidMembers = None
			self.numPerSending = None
			self.skuId = None

		def getapiname(self):
			return 'jingdong.seller.coupon.write.create'

			








from seven_jd.jd.api.base import RestApi

class EclpInsideAddUlOrderRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.outUlNo = None
			self.sellerNo = None
			self.warehouseNo = None
			self.deptNo = None
			self.deliveryMode = None
			self.ulType = None
			self.allowReturnDest = None
			self.allowLackDest = None
			self.destMethod = None
			self.destReason = None
			self.destCompNo = None
			self.receiver = None
			self.receiverPhone = None
			self.email = None
			self.province = None
			self.city = None
			self.county = None
			self.town = None
			self.address = None
			self.backEmail = None
			self.createUser = None
			self.createTime = None
			self.remark = None
			self.orderLine = None
			self.goodsNo = None
			self.goodsName = None
			self.planQty = None
			self.goodsLevel = None
			self.ulItemBatchRequest = None

		def getapiname(self):
			return 'jingdong.eclp.inside.addUlOrder'

			








from seven_jd.jd.api.base import RestApi

class DropshipDpsSearchoutboundorderRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.pageSize = None
			self.page = None
			self.beginDate = None
			self.endDate = None
			self.modifiedBeginDate = None
			self.modifiedEndDate = None

		def getapiname(self):
			return 'jingdong.dropship.dps.searchoutboundorder'

			








from seven_jd.jd.api.base import RestApi

class ExpressFetchElectronicSheetRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.printObject = None
			self.userEnv = None
			self.printTemplate = None

		def getapiname(self):
			return 'jingdong.express.fetch.electronic.sheet'

			
	

class Value(object):
		def __init__(self):
			"""
			"""
			self.customProperty = None


class PrintObject(object):
		def __init__(self):
			"""
			"""
			self.waybillCodes = None
			self.electronicSheetType = None
			self.packageCodes = None
			self.boxCodes = None
			self.orderIds = None
			self.customProperties = None
			self.codeType = None


class UserEnv(object):
		def __init__(self):
			"""
			"""
			self.tradeCode = None


class PrintTemplate(object):
		def __init__(self):
			"""
			"""
			self.paperSize = None








# -*- coding:utf-8 -*-
from Crypto.Cipher import AES
import os
IV_SIZE = 16


def aes_encrypt(m_key, pt):
    """
    :param m_key: ref to class Mkey in tde_client.py
    :param pt: plain text to encrypt
    :return: encrypted value in byte form
    """
    iv = os.urandom(IV_SIZE)
    add = add_bytes_count(pt)
    data = pt + chr(IV_SIZE - len(pt.encode('utf-8')) % IV_SIZE) * add
    crypto = AES.new(m_key.s_key, AES.MODE_CBC, iv)
    encrypt_aes = crypto.encrypt(data.encode('utf-8'))
    return iv + encrypt_aes


def aes_decrypt(m_key, ct):
    """
    :param m_key: ref to class Mkey in tde_client.py
    :param ct: encrypted value in byte form
    :return: plain text
    """
    iv = ct[0:IV_SIZE]
    crypto = AES.new(m_key.s_key, AES.MODE_CBC, iv)
    decrypt_text = crypto.decrypt(ct[IV_SIZE:])
    str_text_decrypted = bytes.decode(decrypt_text, encoding='utf-8')
    return str_text_decrypted[:-ord(str_text_decrypted[-1])]


def wrap(m_key, d_key):
    """
    this wrap method will do AES.CBC directly, without padding operation,
    so if the byte length of d_key not times to 16, None will be returned
    :param m_key: ref to class Mkey in tde_client.py
    :param d_key: plain text, byte length must be times of 16
    :return: None or wrap result in byte form
    """
    if len(d_key.encode('utf-8')) % IV_SIZE != 0:
        return None
    crypto = AES.new(m_key.s_key, AES.MODE_CBC, bytes(16))
    return crypto.encrypt(d_key.encode('utf-8'))


def unwrap(m_key, ct):
    """
    did the reverse operation of wrap
    :param m_key: ref to class Mkey in tde_client.py
    :param ct: data to be unwraped in byte form
    :return:plain text
    """
    crypto = AES.new(m_key.s_key, AES.MODE_CBC, bytes(16))
    text_decrypted = crypto.decrypt(ct)
    str_text_decrypted = bytes.decode(text_decrypted, encoding='utf-8')
    return str_text_decrypted


def add_bytes_count(data):
    count = len(data.encode('utf-8'))
    if count % IV_SIZE != 0:
        add = IV_SIZE - (count % IV_SIZE)
    else:
        add = 16
    return add



from seven_jd.jd.api.base import RestApi

class VcItemAttrApplyCreateRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.ware_group_id = None
			self.public_name = None
			self.ware_ids = None
			self.dim1_vals = None
			self.dim1_sorts = None
			self.dim2_vals = None
			self.dim2_sorts = None
			self.dim1_attr = None
			self.dim2_attr = None
			self.other_dim_attr = None

		def getapiname(self):
			return 'jingdong.vc.item.attr.apply.create'

			








from seven_jd.jd.api.base import RestApi

class ComJdExpressDispatcherApiServiceFetchGoodsCalendarApiFetchGoodsBackwardCalendarRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.districtName = None
			self.fullAddress = None
			self.districtCode = None
			self.townName = None
			self.cityName = None
			self.provinceCode = None
			self.cityCode = None
			self.provinceName = None
			self.orderId = None
			self.detailAddress = None
			self.townCode = None

		def getapiname(self):
			return 'jingdong.com.jd.express.dispatcher.api.service.FetchGoodsCalendarApi.fetchGoodsBackwardCalendar'

			








from seven_jd.jd.api.base import RestApi

class EclpInsideAddLcOrderRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.sellerLcNo = None
			self.sellerNo = None
			self.wareHouseNo = None
			self.deptNo = None
			self.outsideLogicStock = None
			self.insideLogicStock = None
			self.lack = None
			self.orderLine = None
			self.isvGoodsNo = None
			self.outGoodsLevel = None
			self.inGoodsLevel = None
			self.planQty = None

		def getapiname(self):
			return 'jingdong.eclp.inside.addLcOrder'

			








from seven_jd.jd.api.base import RestApi

class MarketToolCouponApiServiceCouponWriteOuterServiceCreateCouponRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.wareGrade = None
			self.num = None
			self.discount = None
			self.strategyParam = None
			self.type = None
			self.skuIdList = None
			self.couponId = None
			self.shareType = None
			self.storeId = None
			self.takeEndTime = None
			self.high = None
			self.takeNum = None
			self.quota = None
			self.officialType = None
			self.beginTime = None
			self.promoteChannel = None
			self.remainNum = None
			self.storeType = None
			self.display = None
			self.busiCode = None
			self.wareChoseType = None
			self.userClass = None
			self.userLevel = None
			self.takeBeginTime = None
			self.validityType = None
			self.takeRule = None
			self.hourCoupon = None
			self.name = None
			self.activityLink = None
			self.days = None
			self.style = None
			self.endTime = None
			self.adWord = None
			self.spuIdList = None
			self.channels = None
			self.channelSelectType = None
			self.selectType = None
			self.platforms = None
			self.appName = None
			self.ip = None
			self.appId = None

		def getapiname(self):
			return 'jingdong.market.tool.coupon.api.service.CouponWriteOuterService.createCoupon'

			








from seven_jd.jd.api.base import RestApi

class EclpCloudQueryOrderInfoRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.machiningNo = None
			self.machiningType = None
			self.timeStart = None
			self.timeEnd = None
			self.warehouseNo = None
			self.tenantId = None

		def getapiname(self):
			return 'jingdong.eclp.cloud.queryOrderInfo'

			








from seven_jd.jd.api.base import RestApi

class VssReportJosSearchBrandPerformanceInfoRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.searchType = None
			self.year = None
			self.month = None
			self.daysCode = None
			self.pageIndex = None
			self.pageSize = None

		def getapiname(self):
			return 'jingdong.vss.report.jos.searchBrandPerformanceInfo'

			








from seven_jd.jd.api.base import RestApi

class InteractCenterApiServiceReadFindRuleByIdAndTypeRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.appName = None
			self.appId = None
			self.channel = None
			self.activityId = None
			self.type = None

		def getapiname(self):
			return 'jingdong.interact.center.api.service.read.findRuleByIdAndType'

			








from seven_jd.jd.api.base import RestApi

class ImgzoneImageUploadRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.belongType = None
			self.accessToken = None
			self.callEnd = None
			self.imgName = None
			self.cateId = None
			self.imgFile = None

		def getapiname(self):
			return 'jingdong.imgzone.image.upload'

			








from seven_jd.jd.api.base import RestApi

class EclpGoodsQueryShopGoodsInfoRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.size = None
			self.current = None
			self.deptNo = None
			self.goodsNo = None
			self.shopNo = None
			self.spGoodsNo = None
			self.isvGoodsNo = None
			self.shopGoodsNoLT = None

		def getapiname(self):
			return 'jingdong.eclp.goods.queryShopGoodsInfo'

			








# -*- coding:utf-8 -*-
from seven_jd.jd.security.tde_client.http_report_client import HttpReportClient
from threading import RLock
from seven_jd.jd.api.base import RestApi
from seven_jd.jd import appinfo
from seven_jd.jd.security.tde import constants
from seven_jd.jd.security.tde.util import tde_status
from seven_jd.jd.security.tde.util import base64_util
from seven_jd.jd.security.tde.util import key_encryption
import rsa
import json
import base64
import time
import hmac
from hashlib import sha256, md5
from enum import Enum
from jd.security.tde.tde_exceptions import *
import traceback
from apscheduler.schedulers.blocking import BlockingScheduler
import threading

VERSION = "2.0.4"
KM_EPOCH = 28800
minutesBuffer = 10 * 60 * 1000


class TdeClientCache(object):
    """
        A singleton Tde Client cache
        use instance method to get a Tde client
        if hits the cache and the cached client's time is available cached value will be return or create a new one
        with the init of the class, a thread witch report logs per hour
    """
    _lock = threading.Lock()
    __instance = None

    def __init__(self):
        self.__cache = dict()
        self.__lock = RLock()
        t = threading.Thread(target=self.__start_schedule)
        t.start()

    def __new__(cls, *args, **kwargs):
        if not cls.__instance:
            with cls._lock:
                if not cls.__instance:
                    cls.__instance = super().__new__(cls, *args, **kwargs)
        return cls.__instance

    def __start_schedule(self):

        scheduler = BlockingScheduler()
        scheduler.add_job(self.__flush_log, 'interval', seconds=3600, id='log_job')
        scheduler.start()

    def __flush_log(self):
        with self.__lock:
            for key in self.__cache.keys():
                self.__cache.get(key)[0].hrlc.flush()

    def instance(self, server_url, access_token, app_key, app_secret):
        """
            get a tde client via the args
        :param server_url: note the the server_url in python just mean domain name,
                hte prefix http:// or https:// will determined by RestApi.getResponse via use ssl equal to false or true
                the suffix say '/routejson' will by append automatically
        :param access_token: worth nothing to say
        :param app_key: worth nothing to say
        :param app_secret: worth nothing to say
        :return: the tde client used to encrypt or decrypt
        """
        with self.__lock:
            client_info = self.__cache.get(access_token)
            if client_info is None or time.time() - client_info[1] >= KM_EPOCH:
                if client_info is not None:
                    client_info[0].hrlc.flush()
                self.__get_instance(server_url, access_token, app_key, app_secret)
            client, _ = self.__cache.get(access_token)
            return client

    def __get_instance(self, server_url, access_token, app_key, app_secret):
        client = TdeClient(server_url, access_token, app_key, app_secret)
        if client is not None:
            self.__cache[access_token] = (client, time.time())


class TdeClient(object):
    """
    get via TdeClientCache in common, you can create your own if happy
    """
    def __init__(self, server_url, access_token, app_key, app_secret):
        self.server_url = server_url
        self.access_token = access_token
        self.app_key = app_key
        self.app_secret = app_secret
        """
        a dict used to store the token info achieve from server, the keys and value(fake value represent by server 
        side key) shown as below
       {'label': 'act', 'start_ts': 'effective', 'end_ts': 'expired',
        'id': 'id', 'key': base64.b64decode('key'),
        'service': 'service', 'stype': 'stype', 'zone': 'zone'}
        """
        self.token = {}
        self.sdk_version = int(VERSION[0])
        self.hrlc = HttpReportClient(self, server_url, access_token, app_key, app_secret)
        self.cache_ks = None
        self.major_key_ver = None
        self.key_chain_is_ready = False
        self.corrupt_key_list = set()
        self.available_key_list = dict()
        self.init_client()

    def init_client(self):
        try:
            self.request_voucher_token()
            self.cache_ks = CacheKeyStore()
            self.hrlc.insert_init_report()
            self.fetch_master_keys()
            if self.key_chain_is_ready is not True:
                raise RuntimeError(tde_status.SDK_HAS_NO_AVAILABLE_KEYS.message)
        except InvalidKeyException as ie:
            self.hrlc.insert_err_report(tde_status.SDK_THROW_JDK_EXCEPTION.code, ie.args[0], traceback.format_exc(), self.hrlc.level['error'])
            raise ie
        except InvalidTokenException as ite:
            self.hrlc.insert_err_report(tde_status.SDK_USE_INVALID_TOKEN.code, ite.args[0], traceback.format_exc(), self.hrlc.level['severe'])
            raise ite
        except MalformedException as me:
            self.hrlc.insert_err_report(tde_status.SDK_THROW_JDK_EXCEPTION.code, me.args[0], traceback.format_exc(), self.hrlc.level['error'])
            raise me
        except ServiceErrorException as se:
            raise se
        except NoValidKeyException as ne:
            raise ne
        except RuntimeError as re:
            self.hrlc.insert_err_report(tde_status.SDK_THROW_JDK_EXCEPTION.code, re.args[0], traceback.format_exc(), self.hrlc.level['error'])
            raise RuntimeError(re.args[0])
        except Exception as e:
            self.hrlc.insert_err_report(tde_status.SDK_INTERNAL_ERROR.code, e.args[0], traceback.format_exc(), self.hrlc.level['error'])
            raise RuntimeError(e.args[0])

    def encrypt_string(self, pt):
        return base64_util.encode_to_string(self.encrypt(pt))

    def encrypt(self, pt):
        self.__validate_token()
        m_key = self.cache_ks.get_enc_key_by_version(self.major_key_ver)
        self.__check_key_status_for_encryption(m_key)
        try:
            ct = m_key.encrypt(pt)
        except Exception as e:
            self.hrlc.statistic[2] += 1
            raise e
        self.hrlc.statistic[0] += 1
        return ct

    def decrypt_string(self, base64str):
        if TdeClient.is_encrypt_data(base64str):
            self.__validate_token()
            st = self.get_cipher_result(base64.b64decode(base64str))
            if st['status'] == 'UnDecryptable':
                self.hrlc.insert_err_report(tde_status.SDK_HAS_NO_CORRESPONDING_DEC_KEYS.code, tde_status.SDK_HAS_NO_CORRESPONDING_DEC_KEYS.message, '', self.hrlc.level['severe'])
                self.hrlc.statistic[3] += 1
                raise NoValidKeyException(tde_status.SDK_HAS_NO_CORRESPONDING_DEC_KEYS.message)
            elif st['status'] == 'Feasible':
                self.hrlc.insert_event_report(tde_status.SDK_TRIGGER_ROTATED_KEY_FETCH.code, tde_status.SDK_TRIGGER_ROTATED_KEY_FETCH.message)
                self.fetch_master_keys()
                if self.cache_ks.has_future_key_id(st['keyid']):
                    self.hrlc.insert_err_report(tde_status.SDK_FAILS_TO_FETCH_UPDATED_KEYS.code, tde_status.SDK_FAILS_TO_FETCH_UPDATED_KEYS.message, '', self.hrlc.level['severe'])
                    self.hrlc.statistic[3] += 1
                    raise NoValidKeyException(tde_status.SDK_FAILS_TO_FETCH_UPDATED_KEYS.message)
            elif st['status'] == 'Malformed':
                self.hrlc.insert_err_report(tde_status.SDK_HAS_CORRUPTED_CIPHER.code, tde_status.SDK_HAS_CORRUPTED_CIPHER.message, '', self.hrlc.level['severe'])
                self.hrlc.statistic[3] += 1
                raise MalformedException(tde_status.SDK_HAS_CORRUPTED_CIPHER.message)
            m_key = self.cache_ks.search_dec_key(st['keyid'])
            self.__check_key_status_for_decryption(m_key)
            try:
                pt = m_key.decrypt(base64.b64decode(base64str))
            except Exception as e:
                self.hrlc.statistic[3] += 1
                raise e
            self.hrlc.statistic[1] += 1
            return pt

    def __check_key_status_for_decryption(self, key):
        if key is None:
            self.hrlc.insert_err_report(tde_status.SDK_HAS_NO_CORRESPONDING_DEC_KEYS.code, tde_status.SDK_HAS_NO_CORRESPONDING_DEC_KEYS.message, '', self.hrlc.level['severe'])
            self.hrlc.statistic[3] += 1
            raise NoValidKeyException(tde_status.SDK_HAS_NO_CORRESPONDING_DEC_KEYS.message)

    def get_cipher_result(self, ct):
        try:
            b0 = ct[0]
            flag = False
            if b0 == constants.CipherTypes.large().id or b0 == constants.CipherTypes.regular().id:
                flag = True
            mk_idx = TdeClient.__extract_key_id(ct, flag)
            if mk_idx is None:
                return {'keyid': None, 'status': 'Malformed', 'strong': False}
            if self.cache_ks.search_dec_key(mk_idx) is not None:
                return {'keyid': mk_idx, 'status': 'Decryptable', 'strong': flag}
            elif self.cache_ks.has_future_key_id(mk_idx):
                return {'keyid': mk_idx, 'status': 'Feasible', 'strong': flag}
            else:
                return {'keyid': None, 'status': 'UnDecryptable', 'strong': False}
        except RuntimeError:
            return {'keyid': None, 'status': 'Malformed', 'strong': False}

    @staticmethod
    def is_encrypt_data(val):
        try:
            if type(val) != str or base64_util.encode_to_string(base64.b64decode(val)) != val:
                return False
            val = base64.b64decode(val)
            b0 = val[0]
            flag = False
            if b0 == constants.CipherTypes.large().id or b0 == constants.CipherTypes.regular().id:
                flag = True
            mk_idx = TdeClient.__extract_key_id(val, flag)
            if mk_idx is not None and len(mk_idx) > 0:
                return True
            return False
        except Exception as e:
            dummy(e)
            return False

    @staticmethod
    def __extract_key_id(ct, strong):
        if strong:
            eid_len = int.from_bytes(ct[1:3], byteorder='big', signed=False)
            if len(ct) - 3 < eid_len:
                return None
            return ct[3:3 + eid_len]
        else:
            if len(ct) - 2 < constants.default_keyid_len:
                return None
            return ct[2:2 + constants.default_keyid_len]

    def __check_key_status_for_encryption(self, key):
        if key is None:
            self.hrlc.insert_err_report(tde_status.SDK_HAS_NO_AVAILABLE_ENC_KEYS.code, tde_status.SDK_HAS_NO_AVAILABLE_ENC_KEYS.message, '', self.hrlc.level['severe'])
            self.hrlc.statistic[2] += 1
            raise NoValidKeyException(tde_status.SDK_HAS_NO_AVAILABLE_ENC_KEYS.message)
        if key.key_status != constants.KeyStatuses.active():
            self.hrlc.insert_err_report(tde_status.SDK_OPERATE_WITH_INACTIVE_KEYS.code, tde_status.SDK_OPERATE_WITH_INACTIVE_KEYS.message, '', self.hrlc.level['error'])
            self.hrlc.statistic[2] += 1
            raise InvalidKeyException(tde_status.SDK_OPERATE_WITH_INACTIVE_KEYS.message)
        if key.key_usage == constants.KeyUsages.n() or key.key_usage == constants.KeyUsages.d():
            self.hrlc.statistic[2] += 1
            raise InvalidKeyPermission('Key Permission Invalid.')
        if key.expired < round(time.time() * 1000):
            self.hrlc.insert_err_report(tde_status.SDK_OPERATE_WITH_EXPIRED_KEYS.code, tde_status.SDK_OPERATE_WITH_EXPIRED_KEYS.message, '', self.hrlc.level['warn'])

    def __validate_token(self):
        if (self.token['start_ts'] - minutesBuffer) > round(time.time() * 1000):
            self.hrlc.insert_err_report(tde_status.SDK_USE_INEFFECTIVE_TOKEN.code, tde_status.SDK_USE_INEFFECTIVE_TOKEN.message, '', self.hrlc.level['severe'])
            raise InvalidTokenException(tde_status.SDK_USE_INEFFECTIVE_TOKEN.message)
        now = round(time.time() * 1000)
        if self.token['end_ts'] >= now:
            token_state = TokenState.VALID
        elif self.token['end_ts'] + constants.token_exp_delta >= now:
            token_state = TokenState.EXPIREWARNING
        else:
            token_state = TokenState.EXPIRED
        if token_state == TokenState.EXPIRED:
            self.hrlc.insert_err_report(tde_status.SDK_USE_HARD_EXPIRED_TOKEN.code, tde_status.SDK_USE_HARD_EXPIRED_TOKEN.message, '', self.hrlc.level['severe'])
            raise InvalidTokenException(tde_status.SDK_USE_HARD_EXPIRED_TOKEN.message)
        elif token_state == TokenState.EXPIREWARNING:
            self.hrlc.insert_err_report(tde_status.SDK_USE_SOFT_EXPIRED_TOKEN.code, tde_status.SDK_USE_SOFT_EXPIRED_TOKEN.message, '', self.hrlc.level['warn'])

    def request_voucher_token(self):
        request = JosVoucherInfoGetRequest(self.server_url, 80)
        request.set_app_info(appinfo(self.app_key, self.app_secret))
        customer_user_id = None
        if self.access_token is not None and self.access_token.startswith("_"):
            customer_user_id = int(self.access_token.lstrip("_"))
        if customer_user_id is None:
            json_response = request.getResponse(self.access_token)
        else:
            request.customerUserId = customer_user_id
            json_response = request.getResponse()
        voucher_info_response = json_response.get('jingdong_jos_voucher_info_get_responce')
        if '0' != voucher_info_response.get('code'):
            raise ServiceErrorException('gw platform error -> %s' % voucher_info_response.get('msg'))
        if '0' != voucher_info_response.get('response').get('errorCode'):
            raise RequestVoucherException(voucher_info_response.get('response').get('errorMsg'))
        voucher = voucher_info_response.get('response').get('data').get('voucher')
        if voucher is None:
            raise RuntimeError('Request Voucher is null')
        token_data = json.loads(base64_util.decode_to_string(voucher))
        pk = rsa.PublicKey.load_pkcs1_openssl_pem(constants.TMS_PROD_TOKEN_PUB_KEY.encode('utf-8'))
        sig = token_data.get('sig')
        data = token_data.get('data')
        external_data = token_data.get('externalData')
        zone = 'CN-0' if external_data is None else external_data.get('zone')
        verify_result = rsa.verify(json.dumps(data, separators=(',', ':')).encode('utf-8'), base64.b64decode(sig), pk)
        if verify_result != 'SHA-256':
            raise InvalidTokenException("Token Signature Validation Failed.")
        service = 'unkown host' if data.get('service') is None else data.get('service')
        self.token = {'label': data.get('act'), 'start_ts': data.get('effective'), 'end_ts': data.get('expired'), 'id': data.get('id'), 'key': base64.b64decode(data.get('key')), 'service': service, 'stype': data.get('stype'), 'zone': zone}

    def fetch_master_keys(self):
        try:
            request = JosMasterKeyGetRequest(self.server_url, 80)
            request.sdk_ver = self.sdk_version
            request.tid = self.token['id']
            request_dict = {'sdk_ver': request.sdk_ver, 'ts': request.ts, 'tid': request.tid}
            request_str = json.dumps(request_dict, separators=(',', ':'))
            request.sig = base64_util \
                .encode_to_string(hmac.new(self.token['key'], request_str
                                           .encode('utf-8'), digestmod=sha256).digest())
            request.set_app_info(appinfo(self.app_key, self.app_secret))
            json_response = request.getResponse(self.access_token)
            response = json_response.get('jingdong_jos_master_key_get_responce').get('response')
            self.corrupt_key_list.clear()
            response_code = response.get('status_code')
            if response_code == 0:
                self.__import_mkeys(response)
            else:
                if response_code in [tde_status.TMS_REQUEST_VERIFY_FAILED.code, tde_status.TMS_TOKEN_EXPIRE.code, tde_status.TMS_NO_AVAILABLE_GRANTS_FOR_SERVICE.code, tde_status.TMS_TOKEN_IS_FROZEN.code, tde_status.TMS_TOKEN_IS_REVOKE.code, tde_status.TMS_DB_DATA_NOTFOUND_ERROR.code]:
                    self.hrlc.insert_err_report(response_code, response.get('status_message'), '', self.hrlc.level['severe'])
                    self.cache_ks.remove_all_m_keys()
                    self.key_chain_is_ready = False
                else:
                    self.hrlc.insert_err_report(response_code, response.get('status_message'), '', self.hrlc.level['error'])
                raise ServiceErrorException(response.get('status_message'))
        except Exception as e:
            dummy(e)
            self.hrlc.insert_err_report(tde_status.SDK_CANNOT_REACH_KMS.code, tde_status.SDK_CANNOT_REACH_KMS.message, traceback.format_exc(), self.hrlc.level['severe'])

    def __import_mkeys(self, response):
        if response.get('enc_service') != self.token['service']:
            self.hrlc.insert_err_report(tde_status.SDK_RECEIVED_WRONG_KEYRESPONSE1.code, tde_status.SDK_RECEIVED_WRONG_KEYRESPONSE1.message, '', self.hrlc.level['error'])
            raise RuntimeError(tde_status.SDK_RECEIVED_WRONG_KEYRESPONSE1.message)
        if response.get('tid') != self.token['id']:
            self.hrlc.insert_err_report(tde_status.SDK_RECEIVED_WRONG_KEYRESPONSE2.code, tde_status.SDK_RECEIVED_WRONG_KEYRESPONSE2.message, '', self.hrlc.level['error'])
            raise RuntimeError(tde_status.SDK_RECEIVED_WRONG_KEYRESPONSE2.message)
        enc_rmv_list = self.cache_ks.get_key_id_list(KStoreType.ENC_STORE)
        dec_rmv_list = self.cache_ks.get_key_id_list(KStoreType.DEC_STORE)
        service_key_list = response.get('service_key_list')
        self.cache_ks.reset_future_key_ids()
        for service_key in service_key_list:
            m_keys = service_key.get('keys')
            self.available_key_list[service_key.get('service')] = len(m_keys) - 1
            # service, kid, key, k_digest, k_ver, effective_ts, exp_ls, k_type, k_usage, k_status
            for m_data in m_keys:
                m_key = Mkey(service_key.get('service'), base64.b64decode(m_data.get('id')), base64.b64decode(m_data.get('key_string')), m_data.get('key_digest'), m_data.get('version'), m_data.get('key_effective'), m_data.get('key_exp'), m_data.get('key_type'), service_key.get('grant_usage'), m_data.get('key_status'))
                if m_key.is_valid:
                    if service_key.get('service') == self.token['service']:
                        self.major_key_ver = service_key.get('current_key_version')
                        self.cache_ks.update_key(m_data.get('id'), m_key, KStoreType.ENC_STORE)
                        if m_data.get('id') in enc_rmv_list:
                            enc_rmv_list.remove(m_data.get('id'))
                    self.cache_ks.update_key(m_data.get('id'), m_key, KStoreType.DEC_STORE)
                    if m_data.get('id') in dec_rmv_list:
                        dec_rmv_list.remove(m_data.get('id'))
                else:
                    self.corrupt_key_list.add(base64_util.encode_to_string(m_data.get('id')))
                self.cache_ks.update_future_key_ids(service_key.get('service'), service_key.get('current_key_version'))
            self.hrlc.insert_key_update_event_report(tde_status.SDK_REPORT_CUR_KEYVER.code, tde_status.SDK_REPORT_CUR_KEYVER.message + str(self.major_key_ver), self.major_key_ver, self.available_key_list)
            self.available_key_list.clear()
            if len(enc_rmv_list) > 0:
                self.cache_ks.remove_keys_via_list(enc_rmv_list, KStoreType.ENC_STORE)
            if len(dec_rmv_list) > 0:
                self.cache_ks.remove_keys_via_list(dec_rmv_list, KStoreType.DEC_STORE)
            self.__send_corrupt_report()
            self.__check_valid_key_chain()

    def __send_corrupt_report(self):
        if len(self.corrupt_key_list) > 0:
            key_ids = 'keyids:' + ','.join(self.corrupt_key_list)
            self.hrlc.insert_err_report(tde_status.SDK_HAS_CORRUPTED_KEYS.code, tde_status.SDK_HAS_CORRUPTED_KEYS.message, key_ids, self.hrlc.level['error'])
            raise CorruptKeyException(tde_status.SDK_HAS_CORRUPTED_KEYS.message)

    def __check_valid_key_chain(self):
        self.key_chain_is_ready = False
        total_count = self.cache_ks.num_of_keys(KStoreType.ENC_STORE) + self.cache_ks.num_of_keys(KStoreType.DEC_STORE)
        if total_count == 0:
            self.hrlc.insert_err_report(tde_status.SDK_HAS_NO_AVAILABLE_KEYS.code, tde_status.SDK_HAS_NO_AVAILABLE_KEYS.message, '', self.hrlc.level['severe'])
            raise NoValidKeyException(tde_status.SDK_HAS_NO_AVAILABLE_KEYS.message)
        self.key_chain_is_ready = True


class JosVoucherInfoGetRequest(RestApi):
    def __init__(self, domain, port=80):
        RestApi.__init__(self, domain, port)
        self.customerUserId = None

    def getapiname(self):
        return 'jingdong.jos.voucher.info.get'


class JosMasterKeyGetRequest(RestApi):
    def __init__(self, domain, port=80):
        RestApi.__init__(self, domain, port)
        self.sig = None
        self.sdk_ver = None
        self.ts = round(time.time() * 1000)
        self.tid = None

    def getapiname(self):
        return 'jingdong.jos.master.key.get'


class KStoreType(Enum):
    ENC_STORE = 1
    DEC_STORE = 2


class TokenState(Enum):
    VALID = 1
    EXPIREWARNING = 2
    EXPIRED = 3


class CacheKeyStore(object):
    threshold_value = 3

    def __init__(self):
        self.enc_key_store = dict()
        self.dec_key_store = dict()
        self.future_key_ids = set()

    def search_dec_key(self, mk_index):
        return self.dec_key_store.get(base64_util.encode_to_string(mk_index), None)

    def num_of_keys(self, k_store_type):
        if k_store_type == KStoreType.ENC_STORE:
            return len(self.enc_key_store)
        else:
            return len(self.dec_key_store)

    def get_enc_key_by_version(self, key_ver):
        for key in self.enc_key_store.keys():
            m_key = self.enc_key_store[key]
            if key_ver == m_key.ver:
                return m_key
        return None

    def update_key(self, base64_index, m_key, k_store_type):
        if KStoreType.ENC_STORE == k_store_type:
            if base64_index not in self.enc_key_store:
                self.enc_key_store[base64_index] = m_key
            else:
                if self.enc_key_store[base64_index].key_status != m_key.key_status:
                    self.enc_key_store[base64_index] = m_key
        else:
            if base64_index not in self.dec_key_store:
                self.dec_key_store[base64_index] = m_key
            else:
                if self.dec_key_store[base64_index].key_status != m_key.key_status:
                    self.dec_key_store[base64_index] = m_key

    def remove_all_m_keys(self):
        self.enc_key_store.clear()
        self.dec_key_store.clear()

    def remove_keys_via_list(self, target_list, k_store_type):
        if k_store_type == KStoreType.ENC_STORE:
            k_store = self.enc_key_store
        else:
            k_store = self.dec_key_store
        for target in target_list:
            if target in k_store:
                del k_store[target]

    def get_key_id_list(self, k_store_type):
        if k_store_type == KStoreType.ENC_STORE:
            return list(self.enc_key_store.keys())
        else:
            return list(self.dec_key_store.keys())

    def reset_future_key_ids(self):
        self.future_key_ids.clear()

    def update_future_key_ids(self, service, max_ver):
        s_index = max_ver + 1
        for idx in range(s_index, s_index + CacheKeyStore.threshold_value):
            self.future_key_ids.add(base64_util.encode_to_string(md5((service + str(idx)).encode(encoding='utf-8')).digest()))

    def has_future_key_id(self, key_id):
        return base64_util.encode_to_string(key_id) in self.future_key_ids


class Mkey(object):
    def __init__(self, service, kid, key, k_digest, k_ver, effective_ts, exp_ls, k_type, k_usage, k_status):
        if service is None or kid is None:
            raise RuntimeError('ID and App fields cannot be null.')
        self.service_identifier = service
        self.id = kid
        self.ver = k_ver
        if k_ver < -1:
            raise MalformedException('Invalid key version.')
        self.key_usage = constants.KeyUsages.from_value(k_usage)
        self.key_status = constants.KeyStatuses.from_value(k_status)
        self.key_type = constants.KeyTypes.from_value(k_type)
        self.is_valid = False
        if key is not None:
            self.key = key
            self.expired = exp_ls
            self.effective = effective_ts
            self.s_key = key[0:16]
        self.key_digest = k_digest
        digest = base64_util.encode_to_string(sha256(key).digest())
        if digest == k_digest:
            self.is_valid = True

    def encrypt(self, text):
        cipher = key_encryption.aes_encrypt(self, text)
        result = constants.CipherTypes.weak().id.to_bytes(length=1, byteorder='big', signed=False) + constants.AlgoTypes.aes_cbc_128().id.to_bytes(length=1, byteorder='big', signed=False) + self.id + cipher
        return result

    def decrypt(self, ct):
        if ct[0] != constants.CipherTypes.weak().id:
            raise RuntimeError('Unmatch CipherText Type.')
        if ct[1] != constants.AlgoTypes.aes_cbc_128().id:
            raise RuntimeError('Unmatch Encryption Algorithm Type: %s' % ct[1])
        if ct[2:len(self.id) + 2] != self.id:
            raise RuntimeError('MalformedException("Unmatch MKey ID.')
        return key_encryption.aes_decrypt(self, ct[2 + len(self.id):])


def dummy(var):
    pass



from seven_jd.jd.api.base import RestApi

class InteractCenterApiServiceWriteCreateGiftActivityRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.appName = None
			self.isPrize = None
			self.batchKey = None
			self.prizeStartTime = None
			self.collectTimes = None
			self.prizeType = None
			self.desc = None
			self.discount = None
			self.couponId = None
			self.skuIds = None
			self.sendCount = None
			self.prizeId = None
			self.activityId = None
			self.prizeLevel = None
			self.quota = None
			self.prizeEndTime = None
			self.validateDay = None
			self.putKey = None
			self.modifier = None
			self.sourceLink = None
			self.isSinglePrize = None
			self.source = None
			self.type = None
			self.modelIds = None
			self.modified = None
			self.rfId = None
			self.startTime = None
			self.id = None
			self.validate = None
			self.isEverydayAward = None
			self.subtitleName = None
			self.created = None
			self.taskIds = None
			self.name = None
			self.sourceCloseLink = None
			self.pictureLink = None
			self.endTime = None
			self.sourceName = None
			self.supplierCode = None
			self.ext = None

		def getapiname(self):
			return 'jingdong.interact.center.api.service.write.createGiftActivity'

			








from seven_jd.jd.api.base import RestApi

class EdiSdvElectronicPolicySearchRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.startTime = None
			self.endTime = None
			self.page = None
			self.pageSize = None

		def getapiname(self):
			return 'jingdong.edi.sdv.electronic.policy.search'

			








from seven_jd.jd.api.base import RestApi

class EclpRtsIsvRtsCancelRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.eclpRtsNo = None
			self.isvRtsNum = None
			self.deptNo = None
			self.deliveryMode = None
			self.warehouseNo = None
			self.supplierNo = None
			self.receiver = None
			self.receiverPhone = None
			self.email = None
			self.province = None
			self.city = None
			self.county = None
			self.town = None
			self.address = None
			self.deptGoodsNo = None
			self.goodsName = None
			self.quantity = None
			self.realQuantity = None
			self.goodsStatus = None

		def getapiname(self):
			return 'jingdong.eclp.rts.isvRtsCancel'

			








from seven_jd.jd.api.base import RestApi

class StationinfojosserviceSaveRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.companyCode = None
			self.stationCode = None
			self.stationName = None
			self.stationAddress = None
			self.provinceId = None
			self.cityId = None
			self.countyId = None
			self.townId = None
			self.orgCode = None
			self.lat = None
			self.lng = None
			self.provinceName = None
			self.cityName = None
			self.countryName = None
			self.townName = None
			self.orgName = None
			self.areaCode = None
			self.areaName = None

		def getapiname(self):
			return 'jingdong.stationinfojosservice.save'

			








from seven_jd.jd.api.base import RestApi

class EclpMasterAddSupplierRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.deptNo = None
			self.isvSupplierNo = None
			self.supplierName = None
			self.contacts = None
			self.phone = None
			self.fax = None
			self.email = None
			self.province = None
			self.city = None
			self.county = None
			self.town = None
			self.address = None
			self.ext1 = None
			self.ext2 = None
			self.ext3 = None
			self.ext4 = None
			self.ext5 = None
			self.pictureUrls = None
			self.medicineEnterpriseNature = None

		def getapiname(self):
			return 'jingdong.eclp.master.addSupplier'

			








from seven_jd.jd.api.base import RestApi

class EclpAfsCreateServiceOrderRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.isvUUId = None
			self.isvSource = None
			self.shopNo = None
			self.departmentNo = None
			self.shipperNo = None
			self.eclpOrderId = None
			self.salePlatformSource = None
			self.salesPlatformCreateTime = None
			self.sourceType = None
			self.pickupType = None
			self.isInvoice = None
			self.invoiceNo = None
			self.isPackage = None
			self.isTestReport = None
			self.customerName = None
			self.customerTel = None
			self.provinceNo = None
			self.provinceName = None
			self.cityName = None
			self.cityNo = None
			self.countyName = None
			self.countyNo = None
			self.townName = None
			self.townNo = None
			self.customerAddress = None
			self.pickupAddress = None
			self.operatorId = None
			self.operatorName = None
			self.operateTime = None
			self.pickupNo = None
			self.questionDesc = None
			self.applyReason = None
			self.amsAuditComment = None
			self.waybill = None
			self.pickwaretype = None
			self.isvGoodsNo = None
			self.quantity = None
			self.weight = None
			self.sn = None
			self.attachmentDetails = None
			self.wareType = None
			self.isCreatePickup = None
			self.businessPhone = None
			self.outPickupType = None
			self.afterSalesChangeNo = None
			self.spOrderId = None

		def getapiname(self):
			return 'jingdong.eclp.afs.createServiceOrder'

			








from seven_jd.jd.api.base import RestApi

class EptOrderGetorderIdsbyqueryRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.orderStatus = None
			self.locked = None
			self.disputed = None
			self.bookTimeBegin = None
			self.bookTimeEnd = None
			self.userPin = None
			self.startRow = None

		def getapiname(self):
			return 'jingdong.ept.order.getorderIdsbyquery'

			








from seven_jd.jd.api.base import RestApi

class VcQueryshippackagepagelistRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.brand_id = None
			self.page_index = None
			self.page_size = None
			self.create_time_begin = None
			self.create_time_end = None

		def getapiname(self):
			return 'jingdong.vc.queryshippackagepagelist'

			








from seven_jd.jd.api.base import RestApi

class EclpRtwQueryRtwRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.eclpSoNo = None
			self.eclpRtwNo = None
			self.isvRtwNum = None
			self.warehouseNo = None
			self.reson = None
			self.orderInType = None
			self.queryBatAttrFlag = None
			self.startCreateTime = None
			self.endCreateTime = None
			self.outStoreNo = None

		def getapiname(self):
			return 'jingdong.eclp.rtw.queryRtw'

			








from seven_jd.jd.api.base import RestApi

class PopPlanAddBeanPlanRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.requestId = None
			self.serviceMoneyBudget = None
			self.accountCode = None
			self.accountType = None
			self.sendTimes = None
			self.type = None
			self.modifyMode = None
			self.content = None
			self.accountId = None
			self.budgetNum = None
			self.name = None
			self.rfId = None
			self.beginTime = None
			self.endTime = None
			self.sendMode = None
			self.sendRule = None
			self.pinRiskLevel = None

		def getapiname(self):
			return 'jingdong.pop.plan.addBeanPlan'

			








from seven_jd.jd.api.base import RestApi

class PrintingTemplateGetTemplateListRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.param1 = None

		def getapiname(self):
			return 'jingdong.printing.template.getTemplateList'

			
	

class Param1(object):
		def __init__(self):
			"""
			"""
			self.templateId = None
			self.templateType = None
			self.wayTempleteType = None
			self.cpCode = None
			self.isvResourceType = None








from seven_jd.jd.api.base import RestApi

class InteractCenterApiServiceWriteCollectBeanRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.appName = None
			self.channel = None
			self.pin = None
			self.ruleId = None
			self.activityId = None
			self.ip = None
			self.source = None
			self.type = None
			self.rfId = None
			self.open_id_buyer = None
			self.xid_buyer = None

		def getapiname(self):
			return 'jingdong.interact.center.api.service.write.collectBean'

			








from seven_jd.jd.api.base import RestApi

class QueryCid3ListByShopId2Request(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.param1 = None

		def getapiname(self):
			return 'jingdong.queryCid3ListByShopId2'

			
	

class Param1(object):
		def __init__(self):
			"""
			"""
			self.jdCarIds = None
			self.pageSize = None
			self.cid2 = None
			self.page = None
			self.cid3 = None
			self.shopId = None
			self.cid1 = None








from seven_jd.jd.api.base import RestApi

class MfaInnerUserUnifiedAuthenticationRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.deviceOSType = None
			self.appId = None
			self.businessType = None
			self.eid = None
			self.openUDID = None
			self.source = None
			self.deviceName = None
			self.email = None
			self.deviceOSVersion = None
			self.pin = None
			self.appVersion = None
			self.loginChannel = None
			self.authType = None
			self.clientIp = None
			self.uuid = None
			self.mobile = None

		def getapiname(self):
			return 'jingdong.mfa.inner.userUnifiedAuthentication'

			








from seven_jd.jd.api.base import RestApi

class EclpRtwGetRtwDifListForMerchantRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.difStartTime = None
			self.difEndTime = None
			self.ownerNo = None
			self.difType = None
			self.eclpWarehouseNo = None
			self.pageNo = None
			self.pageSize = None
			self.manageStatus = None

		def getapiname(self):
			return 'jingdong.eclp.rtw.getRtwDifListForMerchant'

			








from seven_jd.jd.api.base import RestApi

class CreateMemberCardRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.memberCardInfoDTO = None

		def getapiname(self):
			return 'jingdong.createMemberCard'

			
	

class MemberCardInfoDTO(object):
		def __init__(self):
			"""
			"""
			self.birthday = None
			self.gender = None
			self.type = None
			self.pin = None
			self.phone = None
			self.organizations = None
			self.name = None
			self.openTime = None
			self.channelCode = None
			self.open_id_buyer = None
			self.xid_buyer = None








from seven_jd.jd.api.base import RestApi


class CbOrderQueryOrderListRequest(RestApi):
    def __init__(self, domain='gw.api.360buy.com', port=80):
        """
		"""
        RestApi.__init__(self, domain, port)
        self.orderId = None
        self.syncBaseData = None
        self.deliveryType = None
        self.orderStatus = None
        self.queryCount = None
        self.bookTimeEnd = None
        self.carrierCode = None
        self.thirdOrderId = None
        self.bookTimeDesc = None
        self.bookTimeBegin = None
        self.channelId = None
        self.traceId = None
        self.ip = None
        self.appId = None
        self.opName = None
        self.businessIdentity = None
        self.scenario = None
        self.shopId = None
        self.saasTenantCode = None
        self.clientDto_venderId = None
        self.currentPage = None
        self.pageSize = None

    def getapiname(self):
        return 'shangling.cb.order.queryOrderList'



from seven_jd.jd.api.base import RestApi

class EclpOrderEquatorDeclareStorageRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.isvUUID = None
			self.isvSource = None
			self.platformId = None
			self.platformName = None
			self.platformType = None
			self.spSoNo = None
			self.deptNo = None
			self.inJdwms = None
			self.salesPlatformCreateTime = None
			self.venderId = None
			self.venderName = None
			self.consigneeName = None
			self.consigneeMobile = None
			self.consigneePhone = None
			self.consigneeEmail = None
			self.consigneeAddress = None
			self.consigneePostcode = None
			self.consigneeCountry = None
			self.addressProvince = None
			self.addressCity = None
			self.addressCounty = None
			self.addressTown = None
			self.soType = None
			self.expectDate = None
			self.invoiceTitle = None
			self.invoiceContent = None
			self.declareOrder = None
			self.ccProvider = None
			self.ccProviderName = None
			self.postType = None
			self.pattern = None
			self.customs = None
			self.warehouseNo = None
			self.ebpCode = None
			self.ebpName = None
			self.ebcCode = None
			self.ebcName = None
			self.delivery = None
			self.discount = None
			self.discountNote = None
			self.istax = None
			self.taxTotal = None
			self.freight = None
			self.otherPrice = None
			self.goodsValue = None
			self.weight = None
			self.netWeight = None
			self.batchNumbers = None
			self.buyerRegNo = None
			self.buyerPhone = None
			self.buyerName = None
			self.buyerIdType = None
			self.buyerIdNumber = None
			self.senderName = None
			self.senderCompanyName = None
			self.senderCountry = None
			self.senderZip = None
			self.senderCity = None
			self.senderProvince = None
			self.senderTel = None
			self.senderAddr = None
			self.customsRemark = None
			self.declarePaymentList = None
			self.paymentType = None
			self.payCode = None
			self.payName = None
			self.payTransactionId = None
			self.currency = None
			self.paymentConfirmTime = None
			self.shouldPay = None
			self.receiveNo = None
			self.payRemark = None
			self.declareWaybill = None
			self.logisticsCode = None
			self.logisticsName = None
			self.bdOwnerNo = None
			self.logisticsNo = None
			self.packNo = None
			self.logisticsRemark = None
			self.isDelivery = None
			self.receivable = None
			self.consigneeRemark = None
			self.packageMark = None
			self.businessType = None
			self.destinationCode = None
			self.destinationName = None
			self.sendWebsiteCode = None
			self.sendWebsiteName = None
			self.sendMode = None
			self.receiveMode = None
			self.appointDeliveryTime = None
			self.insuredPriceFlag = None
			self.insuredValue = None
			self.insuredFee = None
			self.thirdPayment = None
			self.monthlyAccount = None
			self.shipment = None
			self.sellerRemark = None
			self.thirdSite = None
			self.shopNo = None
			self.isSupervise = None
			self.initalRequest = None
			self.initalResponse = None
			self.payTransactionIdYh = None
			self.isvParentId = None
			self.isvOrderIdList = None
			self.totalAmount = None
			self.verDept = None
			self.payType = None
			self.recpAccount = None
			self.recpCode = None
			self.recpName = None
			self.consNameEN = None
			self.consAddressEN = None
			self.senderNameEN = None
			self.senderCityEN = None
			self.senderAddrEN = None
			self.wrapType = None
			self.consigneeIdType = None
			self.gnum = None
			self.isvGoodsNo = None
			self.spGoodsNo = None
			self.quantity = None
			self.price = None
			self.goodsRemark = None
			self.itemLink = None
			self.productionDate = None
			self.expirationDate = None
			self.packBatchNo = None
			self.poNo = None
			self.lot = None

		def getapiname(self):
			return 'jingdong.eclp.order.equatorDeclareStorage'

			








from seven_jd.jd.api.base import RestApi

class GroupMarketJoinGroupRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.Language = None
			self.appName = None
			self.channel = None
			self.pin = None
			self.groupId = None
			self.nickname = None
			self.id = None
			self.open_id_buyer = None
			self.xid_buyer = None

		def getapiname(self):
			return 'jingdong.groupMarket.joinGroup'

			








from seven_jd.jd.api.base import RestApi

class EclpCoTransportLasWayBillRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.deptNo = None
			self.orderNo = None
			self.senderName = None
			self.senderMobile = None
			self.senderPhone = None
			self.senderAddress = None
			self.receiverName = None
			self.receiverMobile = None
			self.receiverPhone = None
			self.receiverAddress = None
			self.remark = None
			self.isFragile = None
			self.senderTc = None
			self.predictDate = None
			self.isJDOrder = None
			self.isCod = None
			self.receiveable = None
			self.onDoorPickUp = None
			self.pickUpDate = None
			self.isGuarantee = None
			self.guaranteeValue = None
			self.receiptFlag = None
			self.paperFrom = None
			self.rtnReceiverName = None
			self.rtnReceiverMobile = None
			self.rtnReceiverAddress = None
			self.rtnReceiverPhone = None
			self.productType = None
			self.pickUpForNew = None
			self.pickUpAbnormalNumber = None
			self.pickUpReceiverName = None
			self.pickUpReceiverMobile = None
			self.pickUpReceiverPhone = None
			self.pickUpReceiverCode = None
			self.pickUpReceiverAddress = None
			self.isSignPrint = None
			self.sameCityDelivery = None
			self.lasDischarge = None
			self.thirdPayment = None
			self.extendFieldStr = None
			self.servProductName = None
			self.servProductSku = None
			self.servProductNum = None
			self.servCode = None
			self.saleOrderNo = None
			self.upstairsFlag = None
			self.weight = None
			self.length = None
			self.width = None
			self.height = None
			self.installFlag = None
			self.thirdCategoryNo = None
			self.brandNo = None
			self.productSku = None
			self.packageName = None
			self.reverseLwb = None
			self.getOldService = None
			self.openBoxService = None
			self.deliveryInstallService = None
			self.packageIdentityCode = None
			self.price = None
			self.lasInstall = None

		def getapiname(self):
			return 'jingdong.eclp.co.transportLasWayBill'

			








from seven_jd.jd.api.base import RestApi

class PopAfsSoaRefundapplyQueryPageListRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.ids = None
			self.status = None
			self.orderId = None
			self.buyerId = None
			self.buyerName = None
			self.applyTimeStart = None
			self.applyTimeEnd = None
			self.checkTimeStart = None
			self.checkTimeEnd = None
			self.pageIndex = None
			self.pageSize = None
			self.storeId = None
			self.open_id_buyer = None
			self.xid_buyer = None

		def getapiname(self):
			return 'jingdong.pop.afs.soa.refundapply.queryPageList'

			








from seven_jd.jd.api.base import RestApi

class JosVoucherInfoGetRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.access_token = None
			self.customer_user_id = None

		def getapiname(self):
			return 'jingdong.jos.voucher.info.get'

			








from seven_jd.jd.api.base import RestApi

class JosServiceWriteVenderJosShopGiftWriteServiceCloseActivityRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.appName = None
			self.channel = None
			self.activityId = None
			self.activityType = None

		def getapiname(self):
			return 'jingdong.jos.service.write.vender.JosShopGiftWriteService.closeActivity'

			








from seven_jd.jd.api.base import RestApi

class MiniappBrandBenefitReportRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.benId = None
			self.benState = None
			self.openId = None
			self.benType = None
			self.benNo = None
			self.reportTime = None
			self.open_id_buyer = None
			self.xid_buyer = None

		def getapiname(self):
			return 'jingdong.miniapp.brand.benefit.report'

			








from seven_jd.jd.api.base import RestApi

class JosSecretApiReportGetRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.access_token = None
			self.businessId = None
			self.text = None
			self.attribute = None
			self.customer_user_id = None
			self.server_url = None

		def getapiname(self):
			return 'jingdong.jos.secret.api.report.get'

			








from seven_jd.jd.api.base import RestApi

class EclpMasterInsertCategoryRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.categoryNo = None
			self.categoryName = None
			self.superior = None
			self.sortNo = None
			self.memo = None
			self.operateUser = None
			self.operateTime = None

		def getapiname(self):
			return 'jingdong.eclp.master.insertCategory'

			








from seven_jd.jd.api.base import RestApi

class InnovationProductReadGetSkuListRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.spuId = None
			self.skuId = None
			self.pageNo = None
			self.pageSize = None
			self.categoryId = None
			self.title = None

		def getapiname(self):
			return 'jingdong.innovation.product.read.getSkuList'

			








# -*- coding:utf-8 -*-
from socket import AddressFamily
import psutil
import platform
from threading import RLock
import os
from seven_jd.jd.api.base import RestApi
from seven_jd.jd import appinfo
import random
import time
import json

ALPHABET = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz=+-*/_|<>^~@?%&"


class HttpReportClient(object):
    def __init__(self, tde_client, server_url, access_token, app_key, app_secret):
        self.reports = dict()
        self.host_info = HttpReportClient.__get_host_info()
        self.parent = tde_client
        self.server_url = server_url
        self.access_token = access_token
        self.app_key = app_key
        self.app_secret = app_secret
        self.env_label = platform.system() + "|" + platform.version() + "|" + platform.python_version()
        self.type = {"init": 1, "exception": 2, "statistic": 3, "event": 4}
        self.level = {"info": 1, "warn": 2, "error": 3, "severe": 4}
        self.__lock = RLock()
        self.__add_cup_info()
        # statistic record present in long array
        # index: enccnt(0) deccnt(1) encerrcnt(2) decerrcnt(3)
        self.statistic = [0, 0, 0, 0]

    @staticmethod
    def __get_host_info():
        for name, info in psutil.net_if_addrs().items():
            for ip_address in info:
                if AddressFamily.AF_INET == ip_address.family:
                    return ip_address.address
        return "Unknown host"

    def __add_cup_info(self):
        lower_env_label = self.env_label.lower()
        cpu_info = 'Unknown'
        if lower_env_label.find('linux') != -1:
            cpu_info = os.popen('cat /proc/cpuinfo | grep "model name" | uniq').read().split(':')[1].rstrip('\n').strip()
        elif lower_env_label.find('mac') != -1:
            cpu_info = os.popen('sysctl -n machdep.cpu.brand_string').read().rstrip('\n').strip()
        elif lower_env_label.find('windows') != -1:
            cmd_result = os.popen('wmic cpu get name')
            cpu_info = cmd_result.read().replace('Name', '').replace('\n', '', -1).strip()
            cmd_result.read()
        self.env_label = self.env_label + '|' + cpu_info

    def flush(self):
        self.insert_statistic_report()
        self.send_all_reports()

    def send_all_reports(self):
        with self.__lock:
            for key in self.reports.keys():
                val = self.reports[key]
                request = JosSecretApiReportRequest(self.server_url, 80)
                request.businessId = val['businessId']
                request.text = val['text']
                request.attribute = json.dumps(val['attributes'])
                request.set_app_info(appinfo(self.app_key, self.app_secret))
                res = request.getResponse(self.access_token)
                if res is not None and res.get('serviceCode') == 0:
                    del self.reports[key]

    def insert_init_report(self):
        with self.__lock:
            init_msg = {'businessId': ''.join(random.sample(ALPHABET, 40)), 'text': 'INIT', 'attributes': {'type': self.type['init'], 'host': self.host_info, 'level': self.level['info'], 'service': self.parent.token['service'], 'sdk_ver': self.parent.sdk_version, 'env': self.env_label, 'ts': round(time.time() * 1000)}}
            self.reports[self.type['init']] = init_msg

    def insert_statistic_report(self):
        with self.__lock:
            statistic_msg = {'businessId': ''.join(random.sample(ALPHABET, 40)), 'text': 'STATISTIC', 'attributes': {'enccnt': str(self.statistic[0]), 'deccnt': str(self.statistic[1]), 'encerrcnt': str(self.statistic[2]), 'decerrcnt': str(self.statistic[3]), 'type': self.type['statistic'], 'host': self.host_info, 'level': self.level['info'], 'service': self.parent.token['service'], 'sdk_ver': self.parent.sdk_version, 'env': self.env_label, 'ts': round(time.time() * 1000)}}
            self.reports[self.type['statistic']] = statistic_msg
            self.statistic = [0, 0, 0, 0]

    def insert_event_report(self, event_code, event_detail):
        with self.__lock:
            event_msg = {'businessId': ''.join(random.sample(ALPHABET, 40)), 'text': 'EVENT', 'attributes': {'code': event_code, 'event': event_detail, 'type': self.type['event'], 'host': self.host_info, 'level': self.level['info'], 'service': self.parent.token['service'], 'sdk_ver': self.parent.sdk_version, 'env': self.env_label, 'ts': round(time.time() * 1000)}}
            request = JosSecretApiReportRequest(self.server_url, 80)
            request.businessId = event_msg['businessId']
            request.text = event_msg['text']
            request.set_app_info(appinfo(self.app_key, self.app_secret))
            request.getResponse(self.access_token)

    def insert_key_update_event_report(self, event_code, event_detail, major_key_ver, key_list):
        with self.__lock:
            key_update_event_msg = {'businessId': ''.join(random.sample(ALPHABET, 40)), 'text': 'EVENT', 'attributes': {'cur_key': major_key_ver, 'keylist': key_list, 'type': self.type['event'], 'host': self.host_info, 'level': self.level['info'], 'service': self.parent.token['service'], 'sdk_ver': self.parent.sdk_version, 'env': self.env_label, 'ts': round(time.time() * 1000)}}
            request = JosSecretApiReportRequest(self.server_url, 80)
            request.businessId = key_update_event_msg['businessId']
            request.text = key_update_event_msg['text']
            request.attribute = json.dumps(key_update_event_msg['attributes'])
            request.set_app_info(appinfo(self.app_key, self.app_secret))
            request.getResponse(self.access_token)

    def insert_err_report(self, code, detail, stack_trace, level):
        with self.__lock:
            err_msg = {'businessId': ''.join(random.sample(ALPHABET, 40)), 'text': 'EXCEPTION', 'attributes': {'type': self.type['exception'], 'host': self.host_info, 'level': level, 'service': self.parent.token['service'], 'sdk_ver': self.parent.sdk_version, 'env': self.env_label, 'ts': round(time.time() * 1000), 'code': code, 'msg': detail, 'heap': stack_trace}}
            if level == self.level['error'] or level == self.level['severe']:
                request = JosSecretApiReportRequest(self.server_url, 80)
                request.businessId = err_msg['businessId']
                request.text = err_msg['text']
                request.attribute = json.dumps(err_msg['attributes'])
                request.set_app_info(appinfo(self.app_key, self.app_secret))
                request.getResponse(self.access_token)
            else:
                self.reports[code] = err_msg


class JosSecretApiReportRequest(RestApi):
    def __init__(self, domain, port=80):
        RestApi.__init__(self, domain, port)
        self.serverUrl = None
        self.businessId = None
        self.text = None
        self.attribute = None

    def process_with_url_before_request(self, url):
        self.serverUrl = url

    def getapiname(self):
        return 'jingdong.jos.secret.api.report.get'



from seven_jd.jd.api.base import RestApi

class VcItemOldProductUpdateV2Request(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.apply_id = None
			self.leafCid = None
			self.pkg_info = None
			self.intro_mobile = None
			self.video_id = None
			self.original_place = None
			self.purchaser_code = None
			self.design_concept = None
			self.warranty = None
			self.tel = None
			self.cid1 = None
			self.danger_value = None
			self.store_property = None
			self.brand_id = None
			self.en_brand = None
			self.after_sale_desc = None
			self.web_site = None
			self.item_num = None
			self.sku_unit = None
			self.ware_id = None
			self.zh_brand = None
			self.saler_code = None
			self.has_transfer_elec_code = None
			self.name = None
			self.intro_html = None
			self.spuId = None
			self.upcSpuId = None
			self.prop_values = None
			self.prop_alias = None
			self.prop_vid = None
			self.prop_id = None
			self.prop_remark = None
			self.ocrUrl = None
			self.wreadme = None
			self.ext_id = None
			self.ext_values = None
			self.ext_alias = None
			self.ext_remark = None
			self.market_price_gaea = None
			self.dim1_val_gaea = None
			self.dim2_sort_gaea = None
			self.purchase_price_gaea = None
			self.sku_name_gaea = None
			self.item_num_gaea = None
			self.sku_short_title_gaea = None
			self.sku_id_gaea = None
			self.height_gaea = None
			self.member_price_gaea = None
			self.length_gaea = None
			self.weight_gaea = None
			self.upc_gaea = None
			self.dim1_sort_gaea = None
			self.dim2_val_gaea = None
			self.width_gaea = None
			self.structSaleAttrMap = None

		def getapiname(self):
			return 'jingdong.vc.item.oldProduct.updateV2'

			








from seven_jd.jd.api.base import RestApi

class EclpOvasTransportGoodOvasItemsRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.request = None

		def getapiname(self):
			return 'jingdong.eclp.ovas.transportGoodOvasItems'

			
	

class VasRequest(object):
		def __init__(self):
			"""
			"""
			self.serviceCode = None
			self.goodsDemand = None
			self.status = None


class GoodsNoVasRequest(object):
		def __init__(self):
			"""
			"""
			self.goodsNo = None
			self.vasRequestList = None


class Request(object):
		def __init__(self):
			"""
			"""
			self.deptName = None
			self.goodsNoVasRequestList = None
			self.sellerName = None
			self.deptId = None
			self.sellerNo = None
			self.deptNo = None








from seven_jd.jd.api.base import RestApi

class PopCrmShopGiftCloseShopGiftActivityCallBackRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.clientSource = None
			self.shopGiftContentDTO = None

		def getapiname(self):
			return 'jingdong.pop.crm.shopGift.closeShopGiftActivityCallBack'

			
	

class ClientSource(object):
		def __init__(self):
			"""
			"""
			self.appName = None
			self.channel = None


class ShopGiftContentDTO(object):
		def __init__(self):
			"""
			"""
			self.activityId = None








from seven_jd.jd.api.base import RestApi

class KplOpenPolcenterUnsubscribeorderRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.factoryId = None
			self.clientIp = None
			self.mobile = None
			self.orderNum = None
			self.imei = None
			self.wifiMac = None
			self.bussName = None
			self.androidId = None

		def getapiname(self):
			return 'jingdong.kpl.open.polcenter.unsubscribeorder'

			








from seven_jd.jd.api.base import RestApi

class LdopAlphaProviderStockIncreaseRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.operatorCode = None
			self.vendorCode = None
			self.vendorName = None
			self.providerId = None
			self.providerCode = None
			self.providerName = None
			self.branchCode = None
			self.branchName = None
			self.amount = None
			self.operatorTime = None
			self.operatorName = None
			self.state = None

		def getapiname(self):
			return 'jingdong.ldop.alpha.provider.stock.increase'

			








from seven_jd.jd.api.base import RestApi

class ImgzonePictureQueryRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.picture_id = None
			self.picture_cate_id = None
			self.picture_name = None
			self.start_date = None
			self.end_Date = None
			self.page_num = None
			self.page_size = None

		def getapiname(self):
			return 'jingdong.imgzone.picture.query'

			








from seven_jd.jd.api.base import RestApi

class EtmsWaybillSendRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.deliveryId = None
			self.salePlat = None
			self.customerCode = None
			self.orderId = None
			self.thrOrderId = None
			self.selfPrintWayBill = None
			self.pickMethod = None
			self.packageRequired = None
			self.senderName = None
			self.senderAddress = None
			self.senderTel = None
			self.senderMobile = None
			self.senderPostcode = None
			self.receiveName = None
			self.receiveAddress = None
			self.province = None
			self.city = None
			self.county = None
			self.town = None
			self.provinceId = None
			self.cityId = None
			self.countyId = None
			self.townId = None
			self.siteType = None
			self.siteId = None
			self.siteName = None
			self.receiveTel = None
			self.receiveMobile = None
			self.postcode = None
			self.packageCount = None
			self.weight = None
			self.vloumLong = None
			self.vloumWidth = None
			self.vloumHeight = None
			self.vloumn = None
			self.description = None
			self.collectionValue = None
			self.collectionMoney = None
			self.guaranteeValue = None
			self.guaranteeValueAmount = None
			self.signReturn = None
			self.aging = None
			self.transType = None
			self.remark = None
			self.goodsType = None
			self.orderType = None
			self.shopCode = None
			self.orderSendTime = None
			self.warehouseCode = None
			self.areaProvId = None
			self.areaCityId = None
			self.shipmentStartTime = None
			self.shipmentEndTime = None
			self.idNumber = None
			self.addedService = None
			self.extendField1 = None
			self.extendField2 = None
			self.extendField3 = None
			self.extendField4 = None
			self.extendField5 = None
			self.senderCompany = None
			self.receiveCompany = None
			self.freightPre = None
			self.goods = None
			self.goodsCount = None
			self.promiseTimeType = None
			self.freight = None
			self.unpackingInspection = None
			self.fileUrl = None
			self.customerBoxCode = None
			self.customerBoxNumber = None
			self.pickUpStartTime = None
			self.pickUpEndTime = None

		def getapiname(self):
			return 'jingdong.etms.waybill.send'

			








from seven_jd.jd.api.base import RestApi

class DropshipDpsPartitionStockMaintainRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.sku = None
			self.stockNum = None
			self.storeId = None
			self.rfId = None

		def getapiname(self):
			return 'jingdong.dropship.dps.partitionStock.maintain'

			








from seven_jd.jd.api.base import RestApi

class PopPopCommentJsfServiceGetVenderCommentsForJosRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.skuids = None
			self.wareName = None
			self.beginTime = None
			self.endTime = None
			self.score = None
			self.content = None
			self.pin = None
			self.isVenderReply = None
			self.cid = None
			self.orderIds = None
			self.page = None
			self.pageSize = None
			self.open_id_buyer = None
			self.xid_buyer = None

		def getapiname(self):
			return 'jingdong.pop.PopCommentJsfService.getVenderCommentsForJos'

			








from seven_jd.jd.api.base import RestApi

class PromoUnitAddIsvActivityRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.note = None
			self.shared = None
			self.callBackUrl = None
			self.channelType = None
			self.source = None
			self.pluginName = None
			self.imageUrl = None
			self.ruleType = None
			self.name = None
			self.id = None
			self.beginTime = None
			self.endTime = None
			self.isvUrl = None
			self.categoryId = None
			self.status = None
			self.appropriateCrowd = None
			self.priority = None
			self.level = None
			self.activityPrizes = None
			self.marketPurpose = None
			self.recordId = None

		def getapiname(self):
			return 'jingdong.promo.unit.addIsvActivity'

			








from seven_jd.jd.api.base import RestApi

class ExpressOrderUpdateRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.orderInfoUpdateBeforePickupDTO = None

		def getapiname(self):
			return 'jingdong.express.order.update'

			
	

class OrderInfoUpdateBeforePickupDTO(object):
		def __init__(self):
			"""
			"""
			self.deliveryId = None
			self.customerCode = None
			self.weight = None
			self.packageCount = None
			self.volume = None
			self.orderId = None








from seven_jd.jd.api.base import RestApi

class EdiSdvVendorCommentReplySaveRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.username = None
			self.commentId = None
			self.type = None
			self.parentReplyId = None
			self.targetReplyId = None
			self.content = None
			self.venderId = None
			self.ip = None
			self.clientType = None
			self.uuid = None

		def getapiname(self):
			return 'jingdong.edi.sdv.vendor.comment.reply.save'

			








from seven_jd.jd.api.base import RestApi

class SellerPromotionRemovePromoUsersRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.ip = None
			self.port = None
			self.request_id = None
			self.promoId = None
			self.pin = None
			self.beginTime = None
			self.endTime = None
			self.open_id_buyer = None
			self.xid_buyer = None

		def getapiname(self):
			return 'jingdong.seller.promotion.removePromoUsers'

			








# -*- coding: utf-8 -*-
"""
@Author: HuangJingCan
@Date: 2020-04-22 21:25:59
@LastEditTime: 2022-07-27 14:42:39
@LastEditors: HuangJianYi
@Description: 
"""
from __future__ import print_function
from setuptools import setup, find_packages

with open("README.md", "r", encoding='utf-8') as fh:
    long_description = fh.read()

setup(
    name="seven_jd",
    version="1.0.9",
    author="seven",
    author_email="tech@gao7.com",
    description="seven jd",
    long_description=long_description,
    long_description_content_type="text/markdown",
    license="MIT",
    url="http://gitlab.tdtech.gao7.com/TaoBaoCloud/seven_jd.git",
    packages=find_packages(),
    install_requires=[],
    classifiers=[
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
    ],
    python_requires='~=3.4',
)



from seven_jd.jd.api.base import RestApi

class EclpCoEvaluateB2BLwbFreightMainRequest(RestApi):
		def __init__(self,domain='gw.api.360buy.com',port=80):
			"""
			"""
			RestApi.__init__(self,domain, port)
			self.orderNo = None
			self.deptNo = None
			self.senderNickName = None
			self.senderName = None
			self.senderMobile = None
			self.senderPhone = None
			self.senderProvince = None
			self.senderCity = None
			self.senderCounty = None
			self.senderTown = None
			self.senderProvinceName = None
			self.senderCityName = None
			self.senderCountyName = None
			self.senderTownName = None
			self.senderAddress = None
			self.receiverNickName = None
			self.receiverName = None
			self.receiverMobile = None
			self.receiverPhone = None
			self.receiverProvince = None
			self.receiverCity = None
			self.receiverCounty = None
			self.receiverTown = None
			self.receiverProvinceName = None
			self.receiverCityName = None
			self.receiverCountyName = None
			self.receiverTownName = None
			self.remark = None
			self.grossWeight = None
			self.grossVolume = None
			self.createTime = None
			self.createUser = None
			self.receivable = None
			self.isCod = None
			self.vehicleTypeName = None
			self.vehicleTypeNo = None
			self.vehicleQty = None
			self.expressItemName = None
			self.expressItemQty = None
			self.signReceiptFlag = None
			self.deliveryReceiptFlag = None
			self.deliveryIntoWarehouse = None
			self.loadFlag = None
			self.unloadFlag = None
			self.receiptFlag = None
			self.fcFlag = None
			self.guaranteeValue = None
			self.pickupBeginTime = None
			self.pickupEndTime = None
			self.bussinessType = None
			self.deliveryType = None
			self.senderCompany = None
			self.receiverCompany = None
			self.receiverAddress = None
			self.warehouseCode = None
			self.projectName = None
			self.actualSpId = None
			self.coldChainOn = None
			self.temptureNum = None
			self.qingzhenOn = None
			self.yiwuranOn = None
			self.inStorageNo = None
			self.inStorageTime = None
			self.inStorageRemark = None
			self.heavyUpstair = None
			self.wayBillCode = None

		def getapiname(self):
			return 'jingdong.eclp.co.evaluateB2BLwbFreightMain'

			








# -*- coding:utf-8 -*-
class TDEStatus(object):
    def __init__(self, code, message):
        self.code = code
        self.message = message


SUCCESS = TDEStatus(0, "Success")
# Generic error codes across the whole TDE system. Range 1 to 99
INTERNAL_ERROR = TDEStatus(1, "Internal system error.")
DB_ERROR = TDEStatus(2, "Internal database error.")
INVALID_JSON = TDEStatus(3, "Invalid json input.")
# Request json is well - formed but some data field is not valid
INVALID_REQUEST_DATA = TDEStatus(4, "Invalid data in the request json.")
REQUEST_SIG_VERFIFY_ERROR = TDEStatus(5, "Validation of the request signature failed.")
# KMS specific errors.Range 100 to 199
KMS_INTERNAL_ERROR = TDEStatus(100, "KMS internal system error.")
KMS_NO_KEY_FOUND = TDEStatus(101, "No key found on KMS.")
KMS_KEY_CREATED_ALREADY = TDEStatus(102, "MK already created for this service.")
KMS_KEY_REGISTRATION_FAILED = TDEStatus(103, "Failed to register key by RKS.")
KMS_SERVICE_ALREADY_REGISTERED = TDEStatus(104, "The service is already registered")
KMS_TMS_CONNECTION_ERROR = TDEStatus(105, "Failed to connect to TMS server")
KMS_RKS_CONNECTION_ERROR = TDEStatus(106, "Failed to connect to RKS server")
KMS_KEY_ALREADY_ACTIVATED = TDEStatus(107, "Latest key already activated")
KMS_FAIL_TO_REMOVE_REDIS_CACHE = TDEStatus(108, "KMS fail to remove redis cache.")
# SDK specific errors.Range 200 to 299
SDK_INTERNAL_ERROR = TDEStatus(200, "SDK generic exception error.")
# token related
SDK_USE_INEFFECTIVE_TOKEN = TDEStatus(201, "SDK uses an ineffective token.")
SDK_USE_HARD_EXPIRED_TOKEN = TDEStatus(202, "SDK uses an expired token with hard deadline.")
SDK_USE_SOFT_EXPIRED_TOKEN = TDEStatus(203, "SDK uses an expired token with soft deadline.")
# recovery procedure related
SDK_FAIL_TO_READ_BACKUP = TDEStatus(204, "SDK cannot fetch any function keys from backup file.")
# key request / response related
SDK_RECEIVED_WRONG_KEYRESPONSE1 = TDEStatus(205, "SDK received key response with unmatched service name.")
SDK_RECEIVED_WRONG_KEYRESPONSE2 = TDEStatus(206, "SDK received key response with unmatched token id.")
SDK_CANNOT_REACH_KMS = TDEStatus(207, "SDK cannot reach KMS server.")
# Encrypt / Decrypt related
SDK_HAS_NO_AVAILABLE_ENC_KEYS = TDEStatus(208, "SDK holds a decrypt-only token or has no key to encrypt data.")
SDK_HAS_NO_CORRESPONDING_DEC_KEYS = TDEStatus(209, "SDK has no corresponding key to decrypt data.")
SDK_OPERATE_WITH_EXPIRED_KEYS = TDEStatus(210, "SDK uses old keys to encrypt/decrypt data.")
SDK_OPERATE_WITH_INACTIVE_KEYS = TDEStatus(211, "SDK uses suspended/revoked keys to encrypt/decrypt data.")
SDK_THROW_JDK_EXCEPTION = TDEStatus(212, "SDK threw generic JDK exception.")
SDK_USE_INVALID_TOKEN = TDEStatus(213, "SDK uses an invalid token.")
SDK_HAS_NO_AVAILABLE_KEYS = TDEStatus(214, "SDK has no keys in internal cache.")
SDK_HAS_CORRUPTED_KEYS = TDEStatus(215, "SDK has corrupted keys in internal cache.")
SDK_HAS_CORRUPTED_CIPHER = TDEStatus(216, "SDK tries to decrypt corrupted cipher.")
SDK_DIDNOT_SETUP_RPATH = TDEStatus(217, "SDK did not set resource path correctly.")
SDK_FAIL_TO_WRITE_KEYCACHE = TDEStatus(218, "SDK cannot write key cache file to the given resource path.")
SDK_FAIL_TO_DELETE_KEYCACHE = TDEStatus(219, "SDK fails to delete all key cache files.")
SDK_FAIL_TO_READ_KEYCACHE = TDEStatus(220, "SDK cannot fetch any function keys from cache file.")
SDK_FAIL_TO_DELETE_KEYBACKUP = TDEStatus(221, "SDK fails to delete backup file.")
# Event related
SDK_FAILS_TO_FETCH_UPDATED_KEYS = TDEStatus(227, "SDK failed to fetch rotated keys from KMS.")
SDK_TRIGGER_ROTATED_KEY_FETCH = TDEStatus(228, "SDK trigger key fetching because ciphertext is encrypted with newer keys.")
SDK_REPORT_CUR_KEYVER = TDEStatus(229, "CurKeyVer=")

# ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** TMSabout ** ** ** ** ** ** ** ** ** ** ** ** ** ** ** **
# TMS specific errors.Range 300 to 399
TMS_INTERNAL_ERROR = TDEStatus(300, "TMS internal system error.")
TMS_DB_DATA_NOTFOUND_ERROR = TDEStatus(301, "TMS-db's data not found.")
TMS_REQUEST_ARGS_ERROR = TDEStatus(302, "Request argument error.")
TMS_DB_DATA_ERROR = TDEStatus(303, "Tms db data error.")
TMS_KMS_REQUEST_EXPIRE = TDEStatus(304, " KMS request timeout.")
TMS_REQUEST_VERIFY_FAILED = TDEStatus(305, "Request signature validation failed.")
TMS_TOKEN_EXPIRE = TDEStatus(306, "The request token is expired.")
TMS_TOKEN_IS_FROZEN = TDEStatus(307, "The request token is frozen.")
TMS_TOKEN_IS_REVOKE = TDEStatus(308, "The request token is revoked.")
TMS_TOKEN_IS_NOT_IN_THE_EFFECT_TIME_RANGE = TDEStatus(309, "The token is ineffective.")
TMS_TOKEN_IN_DB_IS_NULL = TDEStatus(310, "The token in the db is null.")
TMS_NO_AVAILABLE_GRANTS_FOR_SERVICE = TDEStatus(311, "The token has no granted service.")

# RKS specific errors.Range 400 to 499
RKS_INTERNAL_ERROR = TDEStatus(400, "RKS internal system error.")
RKS_REQUEST_FORMAT_ERROR = TDEStatus(401, "Registration request format error.")
RKS_SIG_VERIFY_ERROR = TDEStatus(402, "Registration request signature validation failed.")
RKS_BACKUP_CLOSE = TDEStatus(403, "Backup service is not available.")


# -*- coding: utf-8 -*-
"""
:Author: HuangJingCan
:Date: 2023-04-03 14:45:50
:LastEditTime: 2023-04-03 15:31:37
:LastEditors: HuangJingCan
:Description: 
"""
from seven_jd.jd.api.rest import *
from seven_jd.jd.api.base import FileItem